aboutsummaryrefslogtreecommitdiffstats
path: root/cmd/utils
diff options
context:
space:
mode:
authorPéter Szilágyi <peterke@gmail.com>2016-06-22 16:59:28 +0800
committerPéter Szilágyi <peterke@gmail.com>2016-06-23 21:43:35 +0800
commitc4de28938ff8c688c4444c8b3e8e28a52cbc62ff (patch)
tree200b60570c19a76c66261f13a4e0777c112b020f /cmd/utils
parent7a5b571c671e70e0e4807cf971c15e2d1e09d33d (diff)
downloadgo-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar.gz
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar.bz2
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar.lz
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar.xz
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.tar.zst
go-tangerine-c4de28938ff8c688c4444c8b3e8e28a52cbc62ff.zip
core: add voting and result tracking for the dao soft-fork
Diffstat (limited to 'cmd/utils')
-rw-r--r--cmd/utils/flags.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmd/utils/flags.go b/cmd/utils/flags.go
index 802e54c73..c732a6635 100644
--- a/cmd/utils/flags.go
+++ b/cmd/utils/flags.go
@@ -163,8 +163,8 @@ var (
}
// Miner settings
// TODO: refactor CPU vs GPU mining flags
- IllegalCodeHashesFlag = cli.StringFlag{
- Name: "illegal-code-hashes",
+ BlockedCodeHashesFlag = cli.StringFlag{
+ Name: "blocked-code-hashes",
Usage: "Comma separated list of code-hashes to ignore any interaction from",
}
MiningEnabledFlag = cli.BoolFlag{
@@ -644,9 +644,9 @@ func MakePasswordList(ctx *cli.Context) []string {
return lines
}
-// ParseIllegalCodeHashes parses a comma separated list of hashes.
-func ParseIllegalCodeHashes(ctx *cli.Context) map[common.Hash]struct{} {
- splittedHexHashes := strings.Split(ctx.GlobalString(IllegalCodeHashesFlag.Name), ",")
+// MakeBlockedCodeHashes parses a comma separated list of hashes.
+func MakeBlockedCodeHashes(ctx *cli.Context) map[common.Hash]struct{} {
+ splittedHexHashes := strings.Split(ctx.GlobalString(BlockedCodeHashesFlag.Name), ",")
illegalCodeHashes := make(map[common.Hash]struct{})
for _, hexHash := range splittedHexHashes {
illegalCodeHashes[common.HexToHash(strings.TrimSpace(hexHash))] = struct{}{}
@@ -690,8 +690,8 @@ func MakeSystemNode(name, version string, relconf release.Config, extra []byte,
}
// Configure the Ethereum service
accman := MakeAccountManager(ctx)
- // parse the illegal code hashes and set them to the core package.
- core.IllegalCodeHashes = ParseIllegalCodeHashes(ctx)
+ // parse the blocked code hashes and set them to the core package.
+ core.BlockedCodeHashes = MakeBlockedCodeHashes(ctx)
// initialise new random number generator
rand := rand.New(rand.NewSource(time.Now().UnixNano()))